# Generated by Django 5.1.1 on 2024-10-18 08:41

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('ognajd', '0003_version_author_version_author_name_and_more'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddIndex(
            model_name='version',
            index=models.Index(fields=['content_type_id', 'object_id'], name='ognajd_vers_content_eebabe_idx'),
        ),
    ]
